==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/mots/lang/mots_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Wichtige Kategorie:</b> Bitte wählen Sie ein Schlüsselwort dieser Gruppe.',
	'avis_doublon_mot_cle' => 'Ein Schlagwort mit dieser Bezeichung gibt es bereits. Wollen sie es wirklich erneut anlegen?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Administratoren der Website',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Redakteure',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Besucher der Website die einen Beitrag in ein Forum geschrieben haben.',

	// C
	'creer_et_associer_un_mot' => 'Schlagwort anlegen und zuordnen',

	// I
	'icone_creation_groupe_mots' => 'Neue Schlagwort-Kategorie anlegen',
	'icone_creation_mots_cles' => 'Neues Schlagwort anlegen',
	'icone_modif_groupe_mots' => 'Schlagwort-Kategorie bearbeiten',
	'icone_modifier_mot' => 'Schlagwort ändern',
	'icone_mots_cles' => 'Schlagworte',
	'icone_supprimer_groupe_mots' => 'Schlagwort-Kategorie löschen',
	'icone_voir_groupe_mots' => 'Diese Schlagwortgruppe anzeigen',
	'icone_voir_tous_mots_cles' => 'Alle Schlagworte anzeigen',
	'info_1_groupe_mots' => 'Eine Schlagwortgruppe',
	'info_articles_lies_mot' => 'Alle Artikel zu diesem Schlagwort',
	'info_aucun_groupe_mots' => 'Keine Schlagwortgruppe',
	'info_aucun_mot_cle' => 'Kein Schlagwort',
	'info_changer_nom_groupe' => 'Namen dieser Kategorie ändern:',
	'info_creation_mots_cles' => 'Hier verwalten Sie die Schlagworte der Website',
	'info_dans_groupe' => 'In der Kategorie:',
	'info_delet_mots_cles' => 'Das Schlagwort <b>@titre_mot@</b> (@type_mot@) ist mit <b>@texte_lie@</b> verknüpft. Sie müssen deshalb das Löschen ausdrücklich bestätigen:',
	'info_groupe_important' => 'Wichtige Kategorie',
	'info_modifier_mot' => 'Schlagwort ändern:',
	'info_mots_cles' => 'Schlagworte',
	'info_mots_cles_association' => 'Schlagworte dieser Kategorie können zugeordnet werden:',
	'info_nb_groupe_mots' => '@nb@ Schlagwortgruppen',
	'info_oui_suppression_mot_cle' => ' ich möchte dieses Schlagwort endgültig löschen.',
	'info_question_mots_cles' => 'Möchten Sie Schlagworte für Ihre Website verwenden?',
	'info_qui_attribue_mot_cle' => 'Schlagworte dieser Kategorie können zugeordnet werden von:',
	'info_remplacer_mot' => '"@titre@" ersetzen',
	'info_retirer_mot' => 'Wort entfernen',
	'info_retirer_mots' => 'Alle Worte entfernen',
	'info_rubriques_liees_mot' => 'Mit diesem Schlagwort verknüpfte Rubriken',
	'info_selection_un_seul_mot_cle' => 'In dieser Kategorie kann man nur <b>ein Schlagwort auf einmal</b> auswählen.',
	'info_supprimer_mot' => 'Wort löschen',
	'info_titre_mot_cle' => 'Name oder Titel des Schlagworts',
	'info_un_mot' => 'Nur ein Wort auf einmal',
	'item_ajout_mots_cles' => 'Schlagworte der Foren erlauben',
	'item_non_ajout_mots_cles' => 'Verwendung von Schlagworten für Foren verhindern',
	'item_non_utiliser_config_groupe_mots_cles' => 'Keine erweiterte Schlagwortkonfiguration verwenden.',
	'item_non_utiliser_mots_cles' => 'Keine Schlagworte verwenden',
	'item_utiliser_config_groupe_mots_cles' => 'Erweiterte Schlagwortkonfiguration verwenden',
	'item_utiliser_mots_cles' => 'Schlagworte verwenden',

	// L
	'lien_ajouter_mot' => 'Dieses Schlagwort hinzufügen',
	'logo_groupe' => 'GRUPPENLOGO',
	'logo_mot_cle' => 'SCHLAGWORT-LOGO',

	// T
	'texte_config_groupe_mots_cles' => 'Möchten Sie die erweiterten Einstellungen für Schlagworte einschalten? Sie können dann z.B. die Zuordnungen auf ein Wort pro Kategorie begrenzen, eine Kategorie als besonders wichtig definieren etc.',
	'texte_mots_cles' => 'Mit Schlagworten können Verbindungen zu thematisch verwandten Artikeln hergestellt werden, die sich in einer anderen Rubrik befinden. Dadurch können Sie eine flexible Navigationsstruktur schaffen oder in Ihren Layoutvorlagen individuelle Benutzer-Layouts ermöglichen.',
	'texte_mots_cles_dans_forum' => 'Dürfen Ihre Besucher Forumsbeiträge verschlagworten? (Achtung! Diese Option ist komplex und sett genaue Kenntnisse voraus.)',
	'texte_nouveau_mot' => 'Neues Wort',
	'titre_config_groupe_mots_cles' => 'Schlagwort-Kategorien einrichten',
	'titre_gauche_mots_edit' => 'WORT NUMMER:',
	'titre_groupe_mots' => 'Schlagwortgruppe',
	'titre_groupe_mots_numero' => 'SCHLAGWORTGRUPPE NO.:',
	'titre_groupes_mots' => 'Schlagwortgruppen',
	'titre_mots_cles_dans_forum' => 'Schlagworte in öffentlichen Foren',
	'titre_mots_tous' => 'Schlagworte',
	'titre_nouveau_groupe' => 'Neue Kategorie',
	'titre_objets_lies_mot' => 'Diesem Schlagwort zugeordnet:',
	'titre_page_mots_tous' => 'Schlagworte'
);

?>

==> spip_3.0.19.orig.tar.xz: spip/plugins-dist/mots/lang/mots_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Wichtige Kategorie:</b> Bitte wählen Sie ein Schlüsselwort dieser Gruppe.',
	'avis_doublon_mot_cle' => 'Ein Schlagwort mit dieser Bezeichung gibt es bereits. Wollen sie es wirklich erneut anlegen?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Administratoren der Website',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Redakteure',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Besucher der Website die einen Beitrag in ein Forum geschrieben haben.',

	// C
	'creer_et_associer_un_mot' => 'Schlagwort anlegen und zuordnen',

	// I
	'icone_creation_groupe_mots' => 'Neue Schlagwort-Kategorie anlegen',
	'icone_creation_mots_cles' => 'Neues Schlagwort anlegen',
	'icone_modif_groupe_mots' => 'Schlagwort-Kategorie bearbeiten',
	'icone_modifier_mot' => 'Schlagwort ändern',
	'icone_mots_cles' => 'Schlagworte',
	'icone_supprimer_groupe_mots' => 'Schlagwort-Kategorie löschen',
	'icone_voir_groupe_mots' => 'Diese Schlagwortgruppe anzeigen',
	'icone_voir_tous_mots_cles' => 'Alle Schlagworte anzeigen',
	'info_1_groupe_mots' => 'Eine Schlagwortgruppe',
	'info_articles_lies_mot' => 'Alle Artikel zu diesem Schlagwort',
	'info_aucun_groupe_mots' => 'Keine Schlagwortgruppe',
	'info_aucun_mot_cle' => 'Kein Schlagwort',
	'info_changer_nom_groupe' => 'Namen dieser Kategorie ändern:',
	'info_creation_mots_cles' => 'Hier verwalten Sie die Schlagworte der Website',
	'info_dans_groupe' => 'In der Kategorie:',
	'info_delet_mots_cles' => 'Das Schlagwort <b>@titre_mot@</b> (@type_mot@) ist mit <b>@texte_lie@</b> verknüpft. Sie müssen deshalb das Löschen ausdrücklich bestätigen:',
	'info_groupe_important' => 'Wichtige Kategorie',
	'info_modifier_mot' => 'Schlagwort ändern:',
	'info_mots_cles' => 'Schlagworte',
	'info_mots_cles_association' => 'Schlagworte dieser Kategorie können zugeordnet werden:',
	'info_nb_groupe_mots' => '@nb@ Schlagwortgruppen',
	'info_oui_suppression_mot_cle' => ' ich möchte dieses Schlagwort endgültig löschen.',
	'info_question_mots_cles' => 'Möchten Sie Schlagworte für Ihre Website verwenden?',
	'info_qui_attribue_mot_cle' => 'Schlagworte dieser Kategorie können zugeordnet werden von:',
	'info_remplacer_mot' => '"@titre@" ersetzen',
	'info_retirer_mot' => 'Wort entfernen',
	'info_retirer_mots' => 'Alle Worte entfernen',
	'info_rubriques_liees_mot' => 'Mit diesem Schlagwort verknüpfte Rubriken',
	'info_selection_un_seul_mot_cle' => 'In dieser Kategorie kann man nur <b>ein Schlagwort auf einmal</b> auswählen.',
	'info_supprimer_mot' => 'Wort löschen',
	'info_titre_mot_cle' => 'Name oder Titel des Schlagworts',
	'info_un_mot' => 'Nur ein Wort auf einmal',
	'item_ajout_mots_cles' => 'Schlagworte der Foren erlauben',
	'item_non_ajout_mots_cles' => 'Verwendung von Schlagworten für Foren verhindern',
	'item_non_utiliser_config_groupe_mots_cles' => 'Keine erweiterte Schlagwortkonfiguration verwenden.',
	'item_non_utiliser_mots_cles' => 'Keine Schlagworte verwenden',
	'item_utiliser_config_groupe_mots_cles' => 'Erweiterte Schlagwortkonfiguration verwenden',
	'item_utiliser_mots_cles' => 'Schlagworte verwenden',

	// L
	'lien_ajouter_mot' => 'Dieses Schlagwort hinzufügen',
	'logo_groupe' => 'GRUPPENLOGO',
	'logo_mot_cle' => 'SCHLAGWORT-LOGO',

	// T
	'texte_config_groupe_mots_cles' => 'Möchten Sie die erweiterten Einstellungen für Schlagworte einschalten? Sie können dann z.B. die Zuordnungen auf ein Wort pro Kategorie begrenzen, eine Kategorie als besonders wichtig definieren etc.',
	'texte_mots_cles' => 'Mit Schlagworten können Verbindungen zu thematisch verwandten Artikeln hergestellt werden, die sich in einer anderen Rubrik befinden. Dadurch können Sie eine flexible Navigationsstruktur schaffen oder in Ihren Layoutvorlagen individuelle Benutzer-Layouts ermöglichen.',
	'texte_mots_cles_dans_forum' => 'Dürfen Ihre Besucher Forumsbeiträge verschlagworten? (Achtung! Diese Option ist komplex und sett genaue Kenntnisse voraus.)',
	'texte_nouveau_mot' => 'Neues Wort',
	'titre_config_groupe_mots_cles' => 'Schlagwort-Kategorien einrichten',
	'titre_gauche_mots_edit' => 'WORT NUMMER:',
	'titre_groupe_mots' => 'Schlagwortgruppe',
	'titre_groupe_mots_numero' => 'SCHLAGWORTGRUPPE NO.:',
	'titre_groupes_mots' => 'Schlagwortgruppen',
	'titre_mots_cles_dans_forum' => 'Schlagworte in öffentlichen Foren',
	'titre_mots_tous' => 'Schlagworte',
	'titre_nouveau_groupe' => 'Neue Kategorie',
	'titre_objets_lies_mot' => 'Diesem Schlagwort zugeordnet:',
	'titre_page_mots_tous' => 'Schlagworte'
);

?>
